@@ -1,11 +1,6 @@
 #!/bin/bash
 #Desktop-session xdg build variables
 
-#Load file mapings
-. /usr/local/lib/desktop-session/desktop-session-file-locations.sh
-#Load Logging Functions
-. $lib_logging
-
 function LOCATIONS {
 LOCATION=$1
 if [ ! -d "$LOCATION" ]; then
